@@ -110,6 +110,9 @@ class PetscConfig:
     def __getitem__(self, item):
         return self.configdict[item]
 
+    def get(self, item, default=None):
+        return self.configdict.get(item, default)
+
     def configure(self, extension, compiler=None):
         self.configure_extension(extension)
         if compiler is not None:
@@ -122,7 +125,7 @@ class PetscConfig:
             'minor'  : re.compile(r"#define\s+PETSC_VERSION_MINOR\s+(\d+)"),
             'micro'  : re.compile(r"#define\s+PETSC_VERSION_SUBMINOR\s+(\d+)"),
             'patch'  : re.compile(r"#define\s+PETSC_VERSION_PATCH\s+(\d+)"),
-            'release': re.compile(r"#define\s+PETSC_VERSION_RELEASE\s+(\d+)"),
+            'release': re.compile(r"#define\s+PETSC_VERSION_RELEASE\s+(-*\d+)"),
             }
         petscversion_h = os.path.join(petsc_dir, 'include', 'petscversion.h')
         with open(petscversion_h, 'rt') as f: data = f.read()
@@ -130,7 +133,7 @@ class PetscConfig:
         minor = int(version_re['minor'].search(data).groups()[0])
         micro = int(version_re['micro'].search(data).groups()[0])
         release = int(version_re['release'].search(data).groups()[0])
-        return  (major, minor, micro), bool(release)
+        return  (major, minor, micro), (release == 1)
 
     def _get_petsc_config(self, petsc_dir, petsc_arch):
         from os.path import join, isdir, exists
@@ -183,7 +186,9 @@ class PetscConfig:
         petsc_inc = flaglist(self['PETSC_CC_INCLUDES'])
         petsc_lib = flaglist(
             '-L%s %s' % (self['PETSC_LIB_DIR'], self['PETSC_LIB_BASIC']))
-        petsc_lib['runtime_library_dirs'].append(self['PETSC_LIB_DIR'])
+        # runtime_library_dirs is not supported on Windows
+        if sys.platform != 'win32':
+            petsc_lib['runtime_library_dirs'].append(self['PETSC_LIB_DIR'])
 
         # Link in extra libraries on static builds
         if self['BUILDSHAREDLIB'] != 'yes':
@@ -195,17 +200,19 @@ class PetscConfig:
 
     def configure_compiler(self, compiler):
         if compiler.compiler_type != 'unix': return
-        (cc, cxx, cflags, ccshared,
-         ldflags, ldshared, so_ext) = get_config_vars(
-            'CC', 'CXX', 'CFLAGS',  'CCSHARED',
-            'LDFLAGS', 'LDSHARED', 'SO')
+        # distutils C/C++ compiler
+        (cc, cflags, ccshared, cxx) = get_config_vars(
+            'CC', 'CFLAGS',  'CCSHARED', 'CXX')
         cflags = cflags or ''
-        ldflags = ldflags or ''
         cflags = cflags.replace('-Wstrict-prototypes', '')
+        ccshared = ccshared or ''
+        # distutils linker
+        (ldflags, ldshared, so_ext) = get_config_vars(
+            'LDFLAGS', 'LDSHARED', 'SO')
         ld = cc
-        ldshared = ldshared.replace(ld, '', 1).strip()
-        ldshared = [flg for flg in split_quoted(ldshared)
-                    if flg not in split_quoted(ldflags)]
+        ldflags = ldflags or ''
+        ldcmd = split_quoted(ld) + split_quoted(ldflags)
+        ldshared = [flg for flg in split_quoted(ldshared) if flg not in ldcmd]
         ldshared = str.join(' ', ldshared)
         #
         getenv = os.environ.get
@@ -216,20 +223,12 @@ class PetscConfig:
         PCC = self['PCC']
         PCC_FLAGS = get_flags(cc) + ' ' + self['PCC_FLAGS']
         PCC_FLAGS = PCC_FLAGS.replace('-fvisibility=hidden', '')
-        if sys.version_info[:2] < (2, 5):
-            PCC_FLAGS = PCC_FLAGS.replace('-Wwrite-strings', '')
         PCC = getenv('PCC', PCC) + ' ' +  getenv('PCCFLAGS', PCC_FLAGS)
         ccshared = getenv('CCSHARED', ccshared)
         cflags   = getenv('CFLAGS',   cflags)
         PCC_SHARED = str.join(' ', (PCC, ccshared, cflags))
         # C++ compiler
-        if self.language == 'c++':
-            PCXX = PCC
-        else:
-            try:
-                PCXX = self['CXX']
-            except KeyError:
-                PCXX = cxx
+        PCXX = PCC if self.language == 'c++' else self.get('CXX', cxx)
         # linker
         PLD = self['PCC_LINKER']
         PLD_FLAGS = get_flags(ld) + ' ' + self['PCC_LINKER_FLAGS']
@@ -601,6 +600,23 @@ class sdist(_sdist):
 
 # --------------------------------------------------------------------
 
+if setuptools:
+    try:
+        from setuptools.command import egg_info as mod_egg_info
+        _FileList = mod_egg_info.FileList
+        class FileList(_FileList):
+            def process_template_line(self, line):
+                level = log.set_threshold(log.ERROR)
+                try:
+                    _FileList.process_template_line(self, line)
+                finally:
+                    log.set_threshold(level)
+        mod_egg_info.FileList = FileList
+    except:
+        pass
+
+# --------------------------------------------------------------------
+
 def append(seq, item):
     if item not in seq:
         seq.append(item)
