@@ -1,9 +1,6 @@
 #ifndef PETSC4PY_CUSTOM_H
 #define PETSC4PY_CUSTOM_H
 
-#undef  __FUNCT__
-#define __FUNCT__ "<petsc4py.PETSc>"
-
 #include "petsc/private/vecimpl.h"
 #include "petsc/private/matimpl.h"
 #include "petsc/private/kspimpl.h"
@@ -28,11 +25,13 @@ typedef PetscErrorCode (*PetscErrorHandlerFunction)
 
 /* ---------------------------------------------------------------- */
 
+#if !defined(PETSC_USE_LOG)
+static PetscStageLog petsc_stageLog = NULL;
+#endif
+
 #define PetscCLASSID(stageLog,index) \
         ((stageLog)->classLog->classInfo[(index)].classid)
 
-#undef __FUNCT__
-#define __FUNCT__ "PetscLogStageFindId"
 static PetscErrorCode
 PetscLogStageFindId(const char name[], PetscLogStage *stageid)
 {
@@ -53,8 +52,6 @@ PetscLogStageFindId(const char name[], PetscLogStage *stageid)
   PetscFunctionReturn(0);
 }
 
-#undef __FUNCT__
-#define __FUNCT__ "PetscLogClassFindId"
 static PetscErrorCode
 PetscLogClassFindId(const char name[], PetscClassId *classid)
 {
@@ -76,8 +73,6 @@ PetscLogClassFindId(const char name[], PetscClassId *classid)
   PetscFunctionReturn(0);
 }
 
-#undef __FUNCT__
-#define __FUNCT__ "PetscLogEventFindId"
 static PetscErrorCode
 PetscLogEventFindId(const char name[], PetscLogEvent *eventid)
 {
@@ -98,8 +93,6 @@ PetscLogEventFindId(const char name[], PetscLogEvent *eventid)
   PetscFunctionReturn(0);
 }
 
-#undef __FUNCT__
-#define __FUNCT__ "PetscLogStageFindName"
 static PetscErrorCode
 PetscLogStageFindName(PetscLogStage stageid,
                       const char *name[])
@@ -115,8 +108,6 @@ PetscLogStageFindName(PetscLogStage stageid,
   PetscFunctionReturn(0);
 }
 
-#undef __FUNCT__
-#define __FUNCT__ "PetscLogClassFindName"
 static PetscErrorCode
 PetscLogClassFindName(PetscClassId classid,
                       const char *name[])
@@ -136,8 +127,6 @@ PetscLogClassFindName(PetscClassId classid,
   PetscFunctionReturn(0);
 }
 
-#undef __FUNCT__
-#define __FUNCT__ "PetscLogEventFindName"
 static PetscErrorCode
 PetscLogEventFindName(PetscLogEvent eventid,
                       const char *name[])
@@ -153,12 +142,34 @@ PetscLogEventFindName(PetscLogEvent eventid,
   PetscFunctionReturn(0);
 }
 
+#if !defined(PETSC_USE_LOG)
+#undef PetscLogEventGetPerfInfo
+static PetscErrorCode
+PetscLogEventGetPerfInfo(int stage,PetscLogEvent event,PetscEventPerfInfo *info)
+{
+  PetscErrorCode ierr;
+  PetscFunctionBegin;
+  PetscValidPointer(info,3);
+  (void)stage; (void)event; /* unused */
+  ierr = PetscMemzero(info,sizeof(PetscEventPerfInfo));CHKERRQ(ierr);
+  PetscFunctionReturn(0);
+}
+#endif
+
 /* ---------------------------------------------------------------- */
 
-#if !defined(PETSC_HAVE_CUSP)
+#if defined(PETSC_HAVE_CUSP)
+
+PETSC_EXTERN PetscErrorCode VecCUSPGetCUDAArrayRead(Vec,PetscScalar**);
+PETSC_EXTERN PetscErrorCode VecCUSPGetCUDAArrayWrite(Vec,PetscScalar**);
+PETSC_EXTERN PetscErrorCode VecCUSPGetCUDAArrayReadWrite(Vec,PetscScalar**);
+
+PETSC_EXTERN PetscErrorCode VecCUSPRestoreCUDAArrayRead(Vec,PetscScalar**);
+PETSC_EXTERN PetscErrorCode VecCUSPRestoreCUDAArrayWrite(Vec,PetscScalar**);
+PETSC_EXTERN PetscErrorCode VecCUSPRestoreCUDAArrayReadWrite(Vec,PetscScalar**);
+
+#else
 
-#undef  __FUNCT__
-#define __FUNCT__ "VecCUSPGetCUDAArray"
 PETSC_STATIC_INLINE PetscErrorCode
 VecCUSPGetCUDAArray(Vec v,PetscScalar **a)
 {
@@ -166,15 +177,13 @@ VecCUSPGetCUDAArray(Vec v,PetscScalar **a)
   PetscValidHeaderSpecific(v,VEC_CLASSID,1);
   PetscValidType(v,1);
   PetscValidPointer(a,2);
-  SETERRQ(PETSC_COMM_SELF,PETSC_ERR_SUP,__FUNCT__"() requires CUSP");
+  SETERRQ1(PETSC_COMM_SELF,PETSC_ERR_SUP,"%s() requires CUSP",PETSC_FUNCTION_NAME);
   PetscFunctionReturn(PETSC_ERR_SUP);
 }
 #define VecCUSPGetCUDAArrayRead      VecCUSPGetCUDAArray
 #define VecCUSPGetCUDAArrayWrite     VecCUSPGetCUDAArray
 #define VecCUSPGetCUDAArrayReadWrite VecCUSPGetCUDAArray
 
-#undef  __FUNCT__
-#define __FUNCT__ "VecCUSPRestoreCUDAArray"
 PETSC_STATIC_INLINE PetscErrorCode
 VecCUSPRestoreCUDAArray(Vec v,PetscScalar **a)
 {
@@ -182,7 +191,7 @@ VecCUSPRestoreCUDAArray(Vec v,PetscScalar **a)
   PetscValidHeaderSpecific(v,VEC_CLASSID,1);
   PetscValidType(v,1);
   PetscValidPointer(a,2);
-  SETERRQ(PETSC_COMM_SELF,PETSC_ERR_SUP,__FUNCT__"() requires CUSP");
+  SETERRQ1(PETSC_COMM_SELF,PETSC_ERR_SUP,"%s() requires CUSP",PETSC_FUNCTION_NAME);
   PetscFunctionReturn(PETSC_ERR_SUP);
 }
 #define VecCUSPRestoreCUDAArrayRead      VecCUSPRestoreCUDAArray
@@ -191,8 +200,6 @@ VecCUSPRestoreCUDAArray(Vec v,PetscScalar **a)
 
 #endif
 
-#undef  __FUNCT__
-#define __FUNCT__ "VecStrideSum"
 PETSC_STATIC_INLINE PetscErrorCode
 VecStrideSum(Vec v, PetscInt start, PetscScalar *a)
 {
@@ -224,8 +231,6 @@ VecStrideSum(Vec v, PetscInt start, PetscScalar *a)
 /* ---------------------------------------------------------------- */
 
 PETSC_STATIC_INLINE
-#undef  __FUNCT__
-#define __FUNCT__ "MatIsPreallocated"
 PetscErrorCode MatIsPreallocated(Mat A,PetscBool *flag)
 {
   PetscFunctionBegin;
@@ -236,8 +241,6 @@ PetscErrorCode MatIsPreallocated(Mat A,PetscBool *flag)
 }
 
 PETSC_STATIC_INLINE
-#undef  __FUNCT__
-#define __FUNCT__ "MatHasPreallocationAIJ"
 PetscErrorCode MatHasPreallocationAIJ(Mat A,PetscBool *aij,PetscBool *baij,PetscBool *sbaij)
 {
   void (*f)(void) = 0;
@@ -268,8 +271,6 @@ typedef PetscErrorCode MatNullSpaceFunction(MatNullSpace,Vec,void*);
 
 /* ---------------------------------------------------------------- */
 
-#undef __FUNCT__
-#define __FUNCT__ "MatFactorInfoDefaults"
 static PetscErrorCode
 MatFactorInfoDefaults(PetscBool incomplete,PetscBool cholesky,
                       MatFactorInfo *info)
@@ -309,8 +310,6 @@ MatFactorInfoDefaults(PetscBool incomplete,PetscBool cholesky,
 
 /* ---------------------------------------------------------------- */
 
-#undef __FUNCT__
-#define __FUNCT__ "KSPSetIterationNumber"
 static PetscErrorCode
 KSPSetIterationNumber(KSP ksp, PetscInt its)
 {
@@ -322,8 +321,6 @@ KSPSetIterationNumber(KSP ksp, PetscInt its)
   PetscFunctionReturn(0);
 }
 
-#undef __FUNCT__
-#define __FUNCT__ "KSPSetResidualNorm"
 static PetscErrorCode
 KSPSetResidualNorm(KSP ksp, PetscReal rnorm)
 {
@@ -335,8 +332,6 @@ KSPSetResidualNorm(KSP ksp, PetscReal rnorm)
   PetscFunctionReturn(0);
 }
 
-#undef __FUNCT__
-#define __FUNCT__ "KSPConvergenceTestCall"
 static PetscErrorCode
 KSPConvergenceTestCall(KSP ksp, PetscInt its, PetscReal rnorm, KSPConvergedReason *reason)
 {
@@ -352,8 +347,6 @@ KSPConvergenceTestCall(KSP ksp, PetscInt its, PetscReal rnorm, KSPConvergedReaso
   PetscFunctionReturn(0);
 }
 
-#undef __FUNCT__
-#define __FUNCT__ "KSPSetConvergedReason"
 static PetscErrorCode
 KSPSetConvergedReason(KSP ksp, KSPConvergedReason reason)
 {
@@ -365,8 +358,6 @@ KSPSetConvergedReason(KSP ksp, KSPConvergedReason reason)
 
 /* ---------------------------------------------------------------- */
 
-#undef __FUNCT__
-#define __FUNCT__ "SNESConvergenceTestCall"
 static PetscErrorCode
 SNESConvergenceTestCall(SNES snes, PetscInt its,
                         PetscReal xnorm, PetscReal ynorm, PetscReal fnorm,
@@ -388,8 +379,6 @@ SNESConvergenceTestCall(SNES snes, PetscInt its,
   PetscFunctionReturn(0);
 }
 
-#undef __FUNCT__
-#define __FUNCT__ "SNESGetUseMFFD"
 static PetscErrorCode
 SNESGetUseMFFD(SNES snes,PetscBool *flag)
 {
@@ -406,8 +395,6 @@ SNESGetUseMFFD(SNES snes,PetscBool *flag)
   PetscFunctionReturn(0);
 }
 
-#undef __FUNCT__
-#define __FUNCT__ "SNESSetUseMFFD"
 static PetscErrorCode
 SNESSetUseMFFD(SNES snes,PetscBool flag)
 {
@@ -459,8 +446,6 @@ SNESSetUseMFFD(SNES snes,PetscBool flag)
   PetscFunctionReturn(0);
 }
 
-#undef __FUNCT__
-#define __FUNCT__ "SNESGetUseFDColoring"
 static PetscErrorCode
 SNESGetUseFDColoring(SNES snes,PetscBool *flag)
 {
@@ -475,8 +460,6 @@ SNESGetUseFDColoring(SNES snes,PetscBool *flag)
   PetscFunctionReturn(0);
 }
 
-#undef __FUNCT__
-#define __FUNCT__ "SNESSetUseFDColoring"
 static PetscErrorCode
 SNESSetUseFDColoring(SNES snes,PetscBool flag)
 {
@@ -514,21 +497,6 @@ SNESSetUseFDColoring(SNES snes,PetscBool flag)
 
 /* ---------------------------------------------------------------- */
 
-#undef __FUNCT__
-#define __FUNCT__ "TSSetTimeStepNumber"
-static PetscErrorCode
-TSSetTimeStepNumber(TS ts, PetscInt step)
-{
-  PetscFunctionBegin;
-  PetscValidHeaderSpecific(ts,TS_CLASSID,1);
-  ts->steps = step;
-  PetscFunctionReturn(0);
-}
-
-/* ---------------------------------------------------------------- */
-
-#undef __FUNCT__
-#define __FUNCT__ "DMDACreateND"
 static PetscErrorCode
 DMDACreateND(MPI_Comm comm,
              PetscInt dim,PetscInt dof,
@@ -558,9 +526,6 @@ DMDACreateND(MPI_Comm comm,
 
 /* ---------------------------------------------------------------- */
 
-#undef  __FUNCT__
-#define __FUNCT__ "<petsc4py.PETSc>"
-
 #endif/* PETSC4PY_CUSTOM_H*/
 
 /*
