@@ -98,14 +98,20 @@ class BaseTestObject(object):
         self.assertFalse(self.obj.fortran)
 
     def testComposeQuery(self):
-        self.assertEqual(self.obj.getRefCount(), 1)
-        self.obj.compose('myobj', self.obj)
+        import copy
+        try:
+            myobj = copy.deepcopy(self.obj)
+        except NotImplementedError:
+            return
+        self.assertEqual(myobj.getRefCount(), 1)
+        self.obj.compose('myobj', myobj)
         self.assertTrue(type(self.obj.query('myobj')) is self.CLASS)
-        self.assertEqual(self.obj.query('myobj'), self.obj)
-        self.assertEqual(self.obj.getRefCount(), 2)
+        self.assertEqual(self.obj.query('myobj'), myobj)
+        self.assertEqual(myobj.getRefCount(), 2)
         self.obj.compose('myobj', None)
-        self.assertEqual(self.obj.getRefCount(), 1)
+        self.assertEqual(myobj.getRefCount(), 1)
         self.assertEqual(self.obj.query('myobj'), None)
+        myobj.destroy()
 
     def testProperties(self):
         self.assertEqual(self.obj.getClassId(),   self.obj.classid)
